HL7v2.Segment.DSC (HL7v2 v3.10.1)

Copy Markdown View Source

Continuation Pointer (DSC) segment — HL7v2 v2.5.1.

Used to indicate that a response is continued in a subsequent message, providing a continuation pointer and style.

2 fields per HL7 v2.5.1 specification.

Summary

Types

t()

@type t() :: %HL7v2.Segment.DSC{
  continuation_pointer: term(),
  continuation_style: term(),
  extra_fields: term()
}