HL7v2.Segment.IVT (HL7v2 v3.10.1)

Copy Markdown View Source

Material Location (IVT) segment — HL7v2 v2.6+ (Chapter 17 Materials Management).

Describes a physical location where inventory items are stored. Used with ITM to define per-location stocking policies, par levels, reorder points, and packaging.

26 fields per HL7 v2.6 specification.

Summary

Types

t()

@type t() :: %HL7v2.Segment.IVT{
  bin_location_identifier: term(),
  consignment_item_indicator: term(),
  default_inventory_asset_account: term(),
  extra_fields: term(),
  inventory_location_identifier: term(),
  inventory_location_name: term(),
  issue_packaging: term(),
  item_importance_code: term(),
  item_status: term(),
  latex_free_substitute_item_identifier: term(),
  operating_room_par_level_indicator: term(),
  order_packaging: term(),
  patient_chargeable_indicator: term(),
  recommended_maximum_days_inventory: term(),
  recommended_order_amount: term(),
  recommended_order_point: term(),
  recommended_reorder_theory: term(),
  recommended_safety_stock_days: term(),
  reusable_cost: term(),
  reusable_item_indicator: term(),
  set_id: term(),
  source_location_identifier: term(),
  source_location_name: term(),
  stocked_item_indicator: term(),
  substitute_item_identifier: term(),
  transaction_amount_unit: term(),
  transaction_code: term()
}