HL7v2.Segment.RXG (HL7v2 v3.10.1)

Copy Markdown View Source

Pharmacy/Treatment Give (RXG) segment — HL7v2 v2.5.1.

Contains information about a single give event for a medication or treatment. 27 fields per HL7 v2.5.1 specification; fields 1-10 and select later fields typed, remainder raw for lossless round-trip.

Summary

Types

t()

@type t() :: %HL7v2.Segment.RXG{
  administration_notes: term(),
  deliver_to_patient_location: term(),
  dispense_sub_id_counter: term(),
  dispense_to_location: term(),
  dispense_to_pharmacy: term(),
  dispense_to_pharmacy_address: term(),
  extra_fields: term(),
  give_amount_maximum: term(),
  give_amount_minimum: term(),
  give_barcode_identifier: term(),
  give_code: term(),
  give_dosage_form: term(),
  give_drug_strength_volume: term(),
  give_drug_strength_volume_units: term(),
  give_per_time_unit: term(),
  give_strength: term(),
  give_strength_units: term(),
  give_sub_id_counter: term(),
  give_units: term(),
  indication: term(),
  needs_human_review: term(),
  pharmacy_order_type: term(),
  pharmacy_treatment_suppliers_special_dispensing_instructions: term(),
  quantity_timing: term(),
  substance_expiration_date: term(),
  substance_lot_number: term(),
  substance_manufacturer_name: term(),
  substitution_status: term()
}