HL7v2.Type.GTS (HL7v2 v3.10.1)

Copy Markdown View Source

General Timing Specification (GTS) -- HL7v2 primitive data type.

An expression representing a general timing specification, following the HL7 timing syntax. Treated as an opaque string -- the library does not parse the timing expression itself.

Summary

Functions

Encodes a GTS value back to a string.

Parses a GTS value. Returns the raw string.

Types

t()

@type t() :: binary() | nil

Functions

encode(value)

@spec encode(t()) :: binary()

Encodes a GTS value back to a string.

Examples

iex> HL7v2.Type.GTS.encode("200602011430-0500")
"200602011430-0500"

iex> HL7v2.Type.GTS.encode(nil)
""

parse(value)

@spec parse(binary() | nil) :: t()

Parses a GTS value. Returns the raw string.

Examples

iex> HL7v2.Type.GTS.parse("200602011430-0500")
"200602011430-0500"

iex> HL7v2.Type.GTS.parse("")
nil

iex> HL7v2.Type.GTS.parse(nil)
nil