Addendum (ADD) segment — HL7v2 v2.5.1.
Defines the continuation of the prior segment when there is not enough room in that segment for the data. Used for very long text continuations.
1 field per HL7 v2.5.1 specification.
@type t() :: %HL7v2.Segment.ADD{ addendum_continuation_pointer: term(), extra_fields: term() }